package com.muyu.market.controller;

import java.time.Instant;
import java.time.LocalDateTime;
import java.time.ZoneId;
import java.time.ZonedDateTime;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import jakarta.servlet.http.HttpServletResponse;
import javax.annotation.Resource;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.market.domain.MyApi;
import com.muyu.market.service.IMyApiService;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.security.utils.SecurityUtils;
import org.springframework.validation.annotation.Validated;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 我的apiController
 *
 * @author 2112A
 * @date 2024-09-06
 */
@RestController
@RequestMapping("/api")
public class MyApiController extends BaseController
{
    @Resource
    private IMyApiService myApiService;

    @PostMapping("/upd")
    public Result updByUserIdAndApiId(@RequestBody MyApi myApi) {
        if(myApi.getMyNum()==0){
            return Result.error("次数不足");
        }
        Long userId = SecurityUtils.getUserId();
        myApi.setUserId(userId);
        return Result.success(myApiService.updByUserIdAndApiId(myApi));
    }

    /**
     * 查询我的api列表
     */
    @RequiresPermissions("api:api:list")
    @GetMapping("/list")
    public Result<TableDataInfo<MyApi>> list(MyApi myApi)
    {
        Long userId = SecurityUtils.getUserId();
        myApi.setUserId(userId);
        startPage();
        List<MyApi> list = myApiService.selectMyApiList(myApi);
        return getDataTable(list);
    }

    /**
     * 导出我的api列表
     */
    @RequiresPermissions("api:api:export")
    @PostMapping("/export")
    public void export(HttpServletResponse response, MyApi myApi)
    {
        List<MyApi> list = myApiService.selectMyApiList(myApi);
        ExcelUtil<MyApi> util = new ExcelUtil<MyApi>(MyApi.class);
        util.exportExcel(response, list, "我的api数据");
    }

    /**
     * 获取我的api详细信息
     */
    @RequiresPermissions("api:api:query")
    @GetMapping(value = "/{myId}")
    public Result<List<MyApi>> getInfo(@PathVariable("myId") Long myId)
    {
        return success(myApiService.selectMyApiByMyId(myId));
    }

    /**
     * 新增我的api
     */
    @RequiresPermissions("api:api:add")
    @PostMapping
    public Result<Integer> add(
            @Validated @RequestBody MyApi myApi)
    {
        if (myApiService.checkIdUnique(myApi)) {
            return error("新增 我的api '" + myApi + "'失败，我的api已存在");
        }
        return toAjax(myApiService.save(myApi));
    }

    /**
     * 修改我的api
     */
    @RequiresPermissions("api:api:edit")
    @PutMapping
    public Result<Integer> edit(
            @Validated @RequestBody MyApi myApi)
    {
        if (!myApiService.checkIdUnique(myApi)) {
            return error("修改 我的api '" + myApi + "'失败，我的api不存在");
        }
        return toAjax(myApiService.updateById(myApi));
    }

    /**
     * 删除我的api
     */
    @RequiresPermissions("api:api:remove")
	@DeleteMapping("/{myIds}")
    public Result<Integer> remove(@PathVariable("myIds") Long[] myIds)
    {
        myApiService.removeBatchByIds(Arrays.asList(myIds));
        return success();
    }



    @PostMapping("/addOrUpd")
    public Result<Integer> addOrUpd(@Validated @RequestBody MyApi myApi)
    {
        Long userId = SecurityUtils.getUserId();
        myApi.setUserId(userId);
        MyApi myApi1 = myApiService.selectMyApiByUserIdAndApiId(userId, myApi.getApiId());
        // 获取当前时间（没有时区）
        LocalDateTime now = LocalDateTime.now();

        // 假设我们使用系统默认时区
        ZoneId zoneId = ZoneId.systemDefault();

        // 将LocalDateTime转换为ZonedDateTime（添加了时区信息）
        ZonedDateTime zdt = now.atZone(zoneId);

        // 将ZonedDateTime转换为Instant（UTC时间线上的点）
        Instant instant = zdt.toInstant();

        // 将Instant转换为Date
        Date date = Date.from(instant);
        myApi.setMyTime(date);
        if (myApi1!=null) {
            myApi.setMyNum(myApi1.getMyNum()+myApi.getMyNum());
            if(myApi1.getMyStates().equals("N")){
                myApi.setMyStates("Y");
            }
            myApi.setMyId(myApi1.getMyId());
            return toAjax(myApiService.updateById(myApi));
        }

        myApi.setMyStates("Y");
        return toAjax(myApiService.save(myApi));
    }
}
