package com.muyu.market.controller;

import java.util.Arrays;
import java.util.List;

import com.muyu.market.domain.SysApitype;
import jakarta.servlet.http.HttpServletResponse;
import javax.annotation.Resource;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.market.domain.ReqMsg;
import com.muyu.market.service.IReqMsgService;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.security.utils.SecurityUtils;
import org.springframework.validation.annotation.Validated;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 请求报文Controller
 *
 * @author 2112A
 * @date 2024-09-05
 */
@RestController
@RequestMapping("/msg")
public class ReqMsgController extends BaseController
{
    @Resource
    private IReqMsgService reqMsgService;

    /**
     * 查询请求报文列表
     */
    @RequiresPermissions("reqmsg:msg:list")
    @GetMapping("/list")
    public Result<TableDataInfo<ReqMsg>> list(ReqMsg reqMsg)
    {
        startPage();
        List<ReqMsg> list = reqMsgService.selectReqMsgList(reqMsg);
        logger.info(list.toString());
        return getDataTable(list);
    }

    /**
     * 导出请求报文列表
     */
    @RequiresPermissions("reqmsg:msg:export")
    @PostMapping("/export")
    public void export(HttpServletResponse response, ReqMsg reqMsg)
    {
        List<ReqMsg> list = reqMsgService.selectReqMsgList(reqMsg);
        ExcelUtil<ReqMsg> util = new ExcelUtil<ReqMsg>(ReqMsg.class);
        util.exportExcel(response, list, "请求报文数据");
    }

    /**
     * 获取请求报文详细信息
     */
    @RequiresPermissions("reqmsg:msg:query")
    @GetMapping(value = "/{reqId}")
    public Result<List<ReqMsg>> getInfo(@PathVariable("reqId") Long reqId)
    {
        return success(reqMsgService.selectReqMsgByReqId(reqId));
    }

    /**
     * 新增请求报文
     */
    @RequiresPermissions("reqmsg:msg:add")
    @PostMapping
    public Result<Integer> add(
            @Validated @RequestBody ReqMsg reqMsg)
    {
        if (reqMsgService.checkIdUnique(reqMsg)) {
            return error("新增 请求报文 '" + reqMsg + "'失败，请求报文已存在");
        }
        return toAjax(reqMsgService.save(reqMsg));
    }

    /**
     * 修改请求报文
     */
    @RequiresPermissions("reqmsg:msg:edit")
    @PutMapping
    public Result<Integer> edit(
            @Validated @RequestBody ReqMsg reqMsg)
    {
        if (!reqMsgService.checkIdUnique(reqMsg)) {
            return error("修改 请求报文 '" + reqMsg + "'失败，请求报文不存在");
        }
        return toAjax(reqMsgService.updateById(reqMsg));
    }

    /**
     * 删除请求报文
     */
    @RequiresPermissions("reqmsg:msg:remove")
	@DeleteMapping("/{reqIds}")
    public Result<Integer> remove(@PathVariable("reqIds") Long[] reqIds)
    {
        reqMsgService.removeBatchByIds(Arrays.asList(reqIds));
        return success();
    }
}
