package com.muyu.market.controller;



import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;

import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.market.config.JavaGetConfig;
import com.muyu.market.config.MobileLocationConfig;
import com.muyu.market.config.SimpleWeatherConfig;
import com.muyu.market.config.ThirdPartyConfig;
import com.muyu.market.domain.Standing;
import com.muyu.market.domain.SysApitype;
import com.muyu.market.domain.UserRole;
import com.muyu.market.service.ISysApitypeService;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * 接口Controller
 *
 * @author ruoyi
 * @date 2024-08-21
 */
@RestController
@RequestMapping("/apitype")
public class SysApitypeController extends BaseController
{
    @Autowired
    private ISysApitypeService sysApitypeService;

    /**
     * 查询接口列表
     */
    @RequiresPermissions("market:apitype:list")
    @GetMapping("/list")
    public Result<TableDataInfo<SysApitype>> list(SysApitype sysApitype)
    {
        startPage();
        List<SysApitype> list = sysApitypeService.selectSysApitypeList(sysApitype);
        return getDataTable(list);
    }

    /**
     * 导出接口列表
     */
    @RequiresPermissions("market:apitype:export")
    @Log(title = "接口", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysApitype sysApitype)
    {
        List<SysApitype> list = sysApitypeService.selectSysApitypeList(sysApitype);
        ExcelUtil<SysApitype> util = new ExcelUtil<SysApitype>(SysApitype.class);
        util.exportExcel(response, list, "接口数据");
    }

    /**
     * 获取接口详细信息
     */
    @RequiresPermissions("market:apitype:query")
    @GetMapping(value = "/{sysId}")
    public Result getInfo(@PathVariable("sysId") Long sysId)
    {
        return success(sysApitypeService.selectSysApitypeBySysId(sysId));
    }

    /**
     * 新增接口
     */
    @RequiresPermissions("market:apitype:add")
    @Log(title = "接口", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody SysApitype sysApitype)
    {
        return toAjax(sysApitypeService.insertSysApitype(sysApitype));
    }

    /**
     * 修改接口
     */
    @RequiresPermissions("market:apitype:edit")
    @Log(title = "接口", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody SysApitype sysApitype)
    {
        return toAjax(sysApitypeService.updateSysApitype(sysApitype));
    }

    /**
     * 删除接口
     */
    @RequiresPermissions("market:apitype:remove")
    @Log(title = "接口", businessType = BusinessType.DELETE)
	@DeleteMapping("/{sysIds}")
    public Result remove(@PathVariable Long[] sysIds)
    {
        return toAjax(sysApitypeService.deleteSysApitypeBySysIds(sysIds));
    }

    @GetMapping("/third/{sysId}/{UnknownValue}")
    public String airQuality(@PathVariable("sysId") Long sysId,@PathVariable("UnknownValue") String UnknownValue) throws Exception{
        if(sysId==1){
            String air = ThirdPartyConfig.airQuality(UnknownValue);
            return air;
        }
        if(sysId==2){
            //String[] value=UnknownValue.split(",");
            String mobile = MobileLocationConfig.queryMobileLocation(UnknownValue);
            return mobile;
        }
        if (sysId==3){
            return SimpleWeatherConfig.queryWeather(UnknownValue);
        }
        return "error";
    }

    @PostMapping("/standing")
    public String standing(@RequestBody Standing standing) throws Exception{
        return JavaGetConfig.standing(standing);
    }

    @PostMapping("/standing/{res}")
    public Result updateCreateByUserId(@PathVariable("res") Integer res) {
        Long userId = SecurityUtils.getUserId();
         UserRole userRole = sysApitypeService.selectUserRoleByUserId(userId);
        if(res!=1||userRole!=null){
            return Result.error();
        }
        return Result.success(sysApitypeService.updateCreateByUserId(userId));
    }
}
