package com.muyu.market.controller;

import java.util.Arrays;
import java.util.List;

import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.market.domain.SysDatawarehouse;
import com.muyu.market.service.ISysDatawarehouseService;
import jakarta.servlet.http.HttpServletResponse;
import javax.annotation.Resource;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.security.annotation.RequiresPermissions;

import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;

import com.muyu.common.security.utils.SecurityUtils;
import org.springframework.validation.annotation.Validated;


/**
 * 订单详情Controller
 *
 * @author 2112A
 * @date 2024-09-01
 */
@RestController
@RequestMapping("/datawarehouse")
public class SysDatawarehouseController extends BaseController
{
    @Resource
    private ISysDatawarehouseService sysDatawarehouseService;

    /**
     * 查询订单详情列表
     */
    @RequiresPermissions("ruleEngine:datawarehouse:list")
    @GetMapping("/list")
    public Result<TableDataInfo<SysDatawarehouse>> list(SysDatawarehouse sysDatawarehouse)
    {
        startPage();
        List<SysDatawarehouse> list = sysDatawarehouseService.selectSysDatawarehouseList(sysDatawarehouse);
        return getDataTable(list);
    }

    /**
     * 导出订单详情列表
     */
    @RequiresPermissions("ruleEngine:datawarehouse:export")
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysDatawarehouse sysDatawarehouse)
    {
        List<SysDatawarehouse> list = sysDatawarehouseService.selectSysDatawarehouseList(sysDatawarehouse);
        ExcelUtil<SysDatawarehouse> util = new ExcelUtil<SysDatawarehouse>(SysDatawarehouse.class);
        util.exportExcel(response, list, "订单详情数据");
    }

    /**
     * 获取订单详情详细信息
     */
    @RequiresPermissions("ruleEngine:datawarehouse:query")
    @GetMapping(value = "/query")
    public Result<List<SysDatawarehouse>> getInfo()
    {
        Long userId = SecurityUtils.getUserId();
        return success(sysDatawarehouseService.selectSysDatawarehouseByUserId(userId));
    }

    /**
     * 新增订单详情
     */
//    @RequiresPermissions("ruleEngine:datawarehouse:add")
//    @PostMapping
//    public Result<Integer> add(
//            @Validated @RequestBody SysDatawarehouse sysDatawarehouse)
//    {
//        if (sysDatawarehouseService.checkIdUnique(sysDatawarehouse)) {
//            return error("新增 订单详情 '" + sysDatawarehouse + "'失败，订单详情已存在");
//        }
//        sysDatawarehouse.setCreateBy(SecurityUtils.getUsername());
//        return toAjax(sysDatawarehouseService.save(sysDatawarehouse));
//    }

    /**
     * 修改订单详情
     */
//    @RequiresPermissions("ruleEngine:datawarehouse:edit")
//    @PutMapping
//    public Result<Integer> edit(
//            @Validated @RequestBody SysDatawarehouse sysDatawarehouse)
//    {
//        if (!sysDatawarehouseService.checkIdUnique(sysDatawarehouse)) {
//            return error("修改 订单详情 '" + sysDatawarehouse + "'失败，订单详情不存在");
//        }
////        sysDatawarehouse.setUpdateBy(SecurityUtils.getUsername());
////        return toAjax(sysDatawarehouseService.updateById(sysDatawarehouse));
//    }

    /**
     * 删除订单详情
     */
    @RequiresPermissions("ruleEngine:datawarehouse:remove")
	@DeleteMapping("/{orderIds}")
    public Result<Integer> remove(@PathVariable("orderIds") Long[] orderIds)
    {
        sysDatawarehouseService.removeBatchByIds(Arrays.asList(orderIds));
        return success();
    }


}
