package com.muyu.market.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.market.domain.SysApitype;
import com.muyu.market.domain.SysFirm;
import com.muyu.market.service.ISysFirminfoService;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Arrays;
import java.util.List;

/**
 * firmListController
 *
 * @author 2112A
 * @date 2024-08-25
 */
@RestController
@RequestMapping("/firminfo")
public class SysFirminfoController extends BaseController
{
    @Autowired
    private ISysFirminfoService sysFirminfoService;

    @PostMapping("/upd/{firmScore}")
    public Result upd(@PathVariable(value = "firmScore") Double firmScore) {
        Long adminsid = SecurityUtils.getUserId();
        return Result.success(sysFirminfoService.upd(adminsid, firmScore));
    }

    /**
     * 查询firmList列表
     */

    @RequiresPermissions("market:firminfo:list")
    @GetMapping("/list")
    public Result<TableDataInfo<SysFirm>> list(SysFirm sysFirm)
    {
        startPage();
        List<SysFirm> list = sysFirminfoService.selectSysFirminfoList(sysFirm);
        return getDataTable(list);
    }

    @RequiresPermissions("market:firminfo:query")
    @GetMapping(value = "/query")
    public Result getInfo()
    {
        Long adminsid = SecurityUtils.getUserId();
        return success(sysFirminfoService.selectSysFirminfoByAdminsid(adminsid));
    }

    @RequiresPermissions("market:firminfo:edit")
    @PostMapping("/edit")
    public Result edit(@RequestBody SysFirm sysFirm)
    {
        return toAjax(sysFirminfoService.updateFirmFromByFirmId(sysFirm));
    }
}
