package com.muyu.market.service.impl;

import java.util.List;

import com.muyu.market.domain.SysDatawarehouse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.muyu.market.mapper.MyApiMapper;
import com.muyu.market.domain.MyApi;
import com.muyu.market.service.IMyApiService;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.StringUtils;
import org.springframework.util.Assert;

/**
 * 我的apiService业务层处理
 *
 * @author 2112A
 * @date 2024-09-06
 */
@Service
public class MyApiServiceImpl
        extends ServiceImpl<MyApiMapper, MyApi>
        implements IMyApiService {

    @Autowired
    private MyApiMapper mapper;

    @Override
    public MyApi selectMyApiByUserIdAndApiId(Long userId, Long apiId) {
        LambdaQueryWrapper<MyApi> queryWrapper = new LambdaQueryWrapper<>();
        Assert.notNull(userId, "userId不可为空");
        queryWrapper.eq(MyApi::getUserId, userId);
        Assert.notNull(apiId, "apiId不可为空");
        queryWrapper.eq(MyApi::getApiId, apiId);
        return this.getOne(queryWrapper);
    }

    @Override
    public Integer updByUserIdAndApiId(MyApi myApi) {
        return mapper.updByUserIdAndApiId(myApi);
    }

    /**
     * 精确查询我的api
     *
     * @param myId 我的api主键
     * @return 我的api
     */
    @Override
    public MyApi selectMyApiByMyId(Long myId)
    {
        LambdaQueryWrapper<MyApi> queryWrapper = new LambdaQueryWrapper<>();
        Assert.notNull(myId, "myId不可为空");
        queryWrapper.eq(MyApi::getMyId, myId);
        return this.getOne(queryWrapper);
    }


    /**
     * 查询我的api列表
     *
     * @param myApi 我的api
     * @return 我的api
     */
    @Override
    public List<MyApi> selectMyApiList(MyApi myApi)
    {
        LambdaQueryWrapper<MyApi> queryWrapper = new LambdaQueryWrapper<>();
        if (myApi.getUserId()!=null){
            queryWrapper.eq(MyApi::getUserId, myApi.getUserId());
        }
        if (myApi.getApiId()!=null){
            queryWrapper.eq(MyApi::getApiId, myApi.getApiId());
        }
        if (myApi.getMyNum()!=null){
            queryWrapper.eq(MyApi::getMyNum, myApi.getMyNum());
        }

        if (StringUtils.isNotEmpty(myApi.getMyStates())){
            queryWrapper.eq(MyApi::getMyStates, myApi.getMyStates());
        }
        return this.list(queryWrapper);
    }

    /**
    * 唯一 判断
    * @param myApi 我的api
     * @return 我的api
    */
    @Override
    public Boolean checkIdUnique(MyApi myApi) {
        LambdaQueryWrapper<MyApi> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(MyApi::getMyId, myApi.getMyId());
        return this.count(queryWrapper) > 0;
    }

}
