package com.muyu.market.service.impl;

import java.util.List;
import org.springframework.stereotype.Service;
import com.muyu.market.mapper.ReqMsgMapper;
import com.muyu.market.domain.ReqMsg;
import com.muyu.market.service.IReqMsgService;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.StringUtils;
import org.springframework.util.Assert;

/**
 * 请求报文Service业务层处理
 *
 * @author 2112A
 * @date 2024-09-05
 */
@Service
public class ReqMsgServiceImpl
        extends ServiceImpl<ReqMsgMapper, ReqMsg>
        implements IReqMsgService {

    /**
     * 精确查询请求报文
     *
     * @param reqId 请求报文主键
     * @return 请求报文
     */
    @Override
    public ReqMsg selectReqMsgByReqId(Long reqId)
    {
        LambdaQueryWrapper<ReqMsg> queryWrapper = new LambdaQueryWrapper<>();
        Assert.notNull(reqId, "reqId不可为空");
        queryWrapper.eq(ReqMsg::getReqId, reqId);
        return this.getOne(queryWrapper);
    }


    /**
     * 查询请求报文列表
     *
     * @param reqMsg 请求报文
     * @return 请求报文
     */
    @Override
    public List<ReqMsg> selectReqMsgList(ReqMsg reqMsg)
    {
        LambdaQueryWrapper<ReqMsg> queryWrapper = new LambdaQueryWrapper<>();
        if (StringUtils.isNotEmpty(reqMsg.getReqName())){
            queryWrapper.like(ReqMsg::getReqName, reqMsg.getReqName());
        }
        if (StringUtils.isNotEmpty(reqMsg.getReqType())){
            queryWrapper.eq(ReqMsg::getReqType, reqMsg.getReqType());
        }
        if (StringUtils.isNotEmpty(reqMsg.getReqYorn())){
            queryWrapper.eq(ReqMsg::getReqYorn, reqMsg.getReqYorn());
        }
        if (StringUtils.isNotEmpty(reqMsg.getReqMsg())){
            queryWrapper.eq(ReqMsg::getReqMsg, reqMsg.getReqMsg());
        }
        if (reqMsg.getSysId()!=null){
            queryWrapper.eq(ReqMsg::getSysId, reqMsg.getSysId());
        }
        return this.list(queryWrapper);
    }

    /**
    * 唯一 判断
    * @param reqMsg 请求报文
     * @return 请求报文
    */
    @Override
    public Boolean checkIdUnique(ReqMsg reqMsg) {
        LambdaQueryWrapper<ReqMsg> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(ReqMsg::getReqId, reqMsg.getReqId());
        return this.count(queryWrapper) > 0;
    }

}
