package com.muyu.market.service.impl;


import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.market.domain.SysDatawarehouse;
import com.muyu.market.mapper.SysDatawarehouseMapper;
import com.muyu.market.service.ISysDatawarehouseService;
import org.springframework.stereotype.Service;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.muyu.common.core.utils.StringUtils;
import org.springframework.util.Assert;

import java.util.List;

/**
 * 订单详情Service业务层处理
 *
 * @author 2112A
 * @date 2024-09-01
 */
@Service
public class SysDatawarehouseServiceImpl
        extends ServiceImpl<SysDatawarehouseMapper, SysDatawarehouse>
        implements ISysDatawarehouseService {

    /**
     * 精确查询订单详情
     *
     * @param userId 订单详情主键
     * @return 订单详情
     */
    @Override
    public List<SysDatawarehouse> selectSysDatawarehouseByUserId(Long userId)
    {
        LambdaQueryWrapper<SysDatawarehouse> queryWrapper = new LambdaQueryWrapper<>();
        Assert.notNull(userId, "userId不可为空");
        queryWrapper.eq(SysDatawarehouse::getUserId, userId);
        return this.list(queryWrapper);
    }


    /**
     * 查询订单详情列表
     *
     * @param sysDatawarehouse 订单详情
     * @return 订单详情
     */
    @Override
    public List<SysDatawarehouse> selectSysDatawarehouseList(SysDatawarehouse sysDatawarehouse)
    {
        LambdaQueryWrapper<SysDatawarehouse> queryWrapper = new LambdaQueryWrapper<>();
        if (StringUtils.isNotEmpty(sysDatawarehouse.getOrderBian())){
            queryWrapper.eq(SysDatawarehouse::getOrderBian, sysDatawarehouse.getOrderBian());
        }
//        if (StringUtils.isNotEmpty(sysDatawarehouse.getOrderTime())){
//            queryWrapper.eq(SysDatawarehouse::getOrderTime, sysDatawarehouse.getOrderTime());
//        }
//        if (StringUtils.isNotEmpty(sysDatawarehouse.getUserId())){
//            queryWrapper.eq(SysDatawarehouse::getUserId, sysDatawarehouse.getUserId());
//        }
        if (StringUtils.isNotEmpty(sysDatawarehouse.getShopName())){
            queryWrapper.like(SysDatawarehouse::getShopName, sysDatawarehouse.getShopName());
        }
        if (StringUtils.isNotEmpty(sysDatawarehouse.getOrderName())){
            queryWrapper.like(SysDatawarehouse::getOrderName, sysDatawarehouse.getOrderName());
        }
        if (StringUtils.isNotEmpty(sysDatawarehouse.getPhone())){
            queryWrapper.eq(SysDatawarehouse::getPhone, sysDatawarehouse.getPhone());
        }
//        if (StringUtils.isNotEmpty(sysDatawarehouse.getOrderScore())){
//            queryWrapper.eq(SysDatawarehouse::getOrderScore, sysDatawarehouse.getOrderScore());
//        }
        if (StringUtils.isNotEmpty(sysDatawarehouse.getPayway())){
            queryWrapper.eq(SysDatawarehouse::getPayway, sysDatawarehouse.getPayway());
        }
        return this.list(queryWrapper);
    }

    /**
    * 唯一 判断
    * @param sysDatawarehouse 订单详情
     * @return 订单详情
    */
    @Override
    public Boolean checkIdUnique(SysDatawarehouse sysDatawarehouse) {
        LambdaQueryWrapper<SysDatawarehouse> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(SysDatawarehouse::getOrderId, sysDatawarehouse.getOrderId());
        return this.count(queryWrapper) > 0;
    }

}
